package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.WyPlatformFeatureBeer;

/**
 * 专题页酒款Service接口
 * 
 * @author ruoyi
 * @date 2025-01-06
 */
public interface IWyPlatformFeatureBeerService 
{
    /**
     * 查询专题页酒款
     * 
     * @param pageId 专题页酒款主键
     * @return 专题页酒款
     */
    public List<WyPlatformFeatureBeer> selectWyPlatformFeatureBeerByPageId(Long pageId);

    /**
     * 查询专题页酒款列表
     * 
     * @param wyPlatformFeatureBeer 专题页酒款
     * @return 专题页酒款集合
     */
    public List<WyPlatformFeatureBeer> selectWyPlatformFeatureBeerList(WyPlatformFeatureBeer wyPlatformFeatureBeer);

    /**
     * 新增专题页酒款
     * 
     * @param wyPlatformFeatureBeer 专题页酒款
     * @return 结果
     */
    public int insertWyPlatformFeatureBeer(WyPlatformFeatureBeer wyPlatformFeatureBeer);

    /**
     * 修改专题页酒款
     * 
     * @param wyPlatformFeatureBeer 专题页酒款
     * @return 结果
     */
    public int updateWyPlatformFeatureBeer(WyPlatformFeatureBeer wyPlatformFeatureBeer);

    /**
     * 批量删除专题页酒款
     * 
     * @param pageIds 需要删除的专题页酒款主键集合
     * @return 结果
     */
    public int deleteWyPlatformFeatureBeerByPageIds(Long[] pageIds);

    /**
     * 删除专题页酒款信息
     * 
     * @param pageId 专题页酒款主键
     * @return 结果
     */
    public int deleteWyPlatformFeatureBeerByPageId(Long pageId);
}
